// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module provides terms for `Dublin Core Metadata Element Set, Version 1.1` vocabulary
//!
//! This module requires `ns-dc11` feature to be enabled.
//!
//! ## Vocabulary:
//!
//! |||
//! |-----|-----|
//! |**Title**|Dublin Core Metadata Element Set, Version 1.1|
//! |**Prefix**|dc11|
//! |**Namespace base IRI**|<http://purl.org/dc/elements/1.1/>|
//! |**Description**||
//! |**Is defined by**|<http://purl.org/dc/elements/1.1/>|
//!

use crate::namespace;

namespace!(
    "http://purl.org/dc/elements/1.1/",;
    /// ``: 
    NAMESPACE_BASE, "",
    /// `Contributor`: An entity responsible for making contributions to the resource.
    contributor, "contributor",
    /// `Coverage`: The spatial or temporal topic of the resource, spatial applicability of the resource, or jurisdiction under which the resource is relevant.
    coverage, "coverage",
    /// `Creator`: An entity primarily responsible for making the resource.
    creator, "creator",
    /// `Date`: A point or period of time associated with an event in the lifecycle of the resource.
    date, "date",
    /// `Description`: An account of the resource.
    description, "description",
    /// `Format`: The file format, physical medium, or dimensions of the resource.
    format, "format",
    /// `Identifier`: An unambiguous reference to the resource within a given context.
    identifier, "identifier",
    /// `Language`: A language of the resource.
    language, "language",
    /// `Publisher`: An entity responsible for making the resource available.
    publisher, "publisher",
    /// `Relation`: A related resource.
    relation, "relation",
    /// `Rights`: Information about rights held in and over the resource.
    rights, "rights",
    /// `Source`: A related resource from which the described resource is derived.
    source, "source",
    /// `Subject`: The topic of the resource.
    subject, "subject",
    /// `Title`: A name given to the resource.
    title, "title",
    /// `Type`: The nature or genre of the resource.
    type_, "type"
);
